Method: HTTParty::ClassMethods#query_string_normalizer

Defined in:
lib/httparty.rb

#query_string_normalizer(normalizer) {|Hash, String| ... } ⇒ Object

Override the way query strings are normalized. Helpful for overriding the default rails normalization of Array queries.

For a query:

get '/', :query => {:selected_ids => [1,2,3]}

The default query string normalizer returns:

/?selected_ids[]=1&selected_ids[]=2&selected_ids[]=3

Let’s change it to this:

/?selected_ids=1&selected_ids=2&selected_ids=3

Pass a Proc to the query normalizer which accepts the yielded query.

Examples:

Modifying Array query strings

class ServiceWrapper
  include HTTParty

  query_string_normalizer proc { |query|
    query.map do |key, value|
      value.map {|v| "#{key}=#{v}"}
    end.join('&')
  }
end

Parameters:

  • normalizer (Proc)

    custom query string normalizer.

Yields:

  • (Hash, String)

    query string

Yield Returns:

  • (Array)

    an array that will later be joined with ‘&’



290
291
292
# File 'lib/httparty.rb', line 290

def query_string_normalizer(normalizer)
  default_options[:query_string_normalizer] = normalizer
end